# event-web-scout

![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/geeeezmo/event-web-scout/ci.yml?label=Build)

![GitHub Latest Pre-Release)](https://img.shields.io/github/v/release/geeeezmo/event-web-scout?include_prereleases&label=pre-release&logo=github)  
![GitHub Latest Release)](https://img.shields.io/github/v/release/geeeezmo/event-web-scout?logo=github)
![GitHub Release Date - Published_At](https://img.shields.io/github/release-date/geeeezmo/event-web-scout)

![PyPI - Version](https://img.shields.io/pypi/v/event-web-scout?label=PyPI%20version)
